==> erp5.recipe.w3validator-1.0.0.tar.gz: erp5.recipe.w3validator-1.0.0/src/erp5/recipe/w3validator/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2011 Nexedi SA and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import os
import shutil
import logging
import zc.recipe.egg
from zc.buildout.download import Download

class Recipe(object):
  def __init__(self, buildout, name, options):
    self.buildout, self.options, self.name = buildout, options, name
    self.egg = zc.recipe.egg.Egg(buildout, options['recipe'], options)
    self.logger=logging.getLogger(self.name)
    options['location'] = os.path.join(
        buildout['buildout']['parts-directory'],
        self.name)
    options.setdefault('validator-url',
                       'http://validator.w3.org/validator.tar.gz')
    options.setdefault('dtd-url',
                       'http://validator.w3.org/sgml-lib.tar.gz')
    options.setdefault('perl-path',
                       '/usr/bin/perl')
    options.setdefault('config-path',
                       '')

  def install(self):
    options = self.options
    location = options['location']
    if os.path.exists(location):
      shutil.rmtree(location)
    os.mkdir(location)
    os.chdir(location)

    # download and extract tarballs
    for url in (options['validator-url'], options['dtd-url']):
      download_file, is_temp = Download(self.buildout['buildout'],
                                        logger=self.logger)(url)
      status = os.system('tar xzf ' + download_file)
      assert status == 0
      if is_temp:
        os.remove(download_file)

    dir_name = [x for x in os.listdir('.') if os.path.isdir(x)][0]
    assert dir_name.startswith('validator')
    for i in os.listdir(dir_name):
      shutil.move(os.path.join(dir_name, i), i)
    os.rmdir(dir_name)

    # modify cgi script
    cgi_path = os.path.join(location, 'httpd', 'cgi-bin', 'check')
    cgi = file(cgi_path).read()
    cgi = cgi.replace('#!/usr/bin/perl', '#!%s' % options['perl-path'])
    default_config_path = os.path.join(location, 'htdocs', 'config',
                                       'validator.conf')
    cgi = cgi.replace('/etc/w3c/validator.conf',
                options['config-path'] or \
                default_config_path)
    file(cgi_path, 'w').write(cgi)

    # modify config file
    if not options['config-path']:
      config_path = default_config_path
      config = file(config_path).read()
      config = config.replace('#Base = /usr/local/validator',
                     'Base = %s' % location)
      file(config_path, 'w').write(config)

    return [location,]

  def update(self):
    pass

==> erp5.recipe.w3validator-1.0.1.tar.gz: erp5.recipe.w3validator-1.0.1/src/erp5/recipe/w3validator/__init__.py <==
# -*- coding: utf-8 -*-
##############################################################################
#
# Copyright (c) 2011 Nexedi SA and Contributors. All Rights Reserved.
# Copyright (c) 2006-2008 Zope Corporation and Contributors.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

import os
import shutil
import logging
import setuptools.archive_util
import zc.recipe.egg
from zc.buildout.download import Download

class Recipe(object):
  def __init__(self, buildout, name, options):
    self.buildout, self.options, self.name = buildout, options, name
    self.egg = zc.recipe.egg.Egg(buildout, options['recipe'], options)
    self.logger=logging.getLogger(self.name)
    options['location'] = os.path.join(
        buildout['buildout']['parts-directory'],
        self.name)
    # Optional 'validator-md5'
    options.setdefault('validator-url',
                       'http://validator.w3.org/validator.tar.gz')
    options.setdefault('dtd-url',
                       'http://validator.w3.org/sgml-lib.tar.gz')
    # Optional 'dtd-md5'
    options.setdefault('perl-path',
                       '/usr/bin/perl')
    options.setdefault('config-path',
                       '')

  def install(self):
    options = self.options
    location = options['location']
    if os.path.exists(location):
      shutil.rmtree(location)
    os.mkdir(location)
    os.chdir(location)

    # download and extract tarballs
    for url, md5sum in [(options['validator-url'], options.get('validator-md5')),
                        (options['dtd-url'], options.get('dtd-md5'))]:
      download_file, is_temp = Download(self.buildout['buildout'],
                                        logger=self.logger)(url, md5sum)
      setuptools.archive_util.unpack_archive(
        download_file, '.')
      if is_temp:
        os.remove(download_file)

    dir_name = [x for x in os.listdir('.') if os.path.isdir(x)][0]
    assert dir_name.startswith('validator')
    for i in os.listdir(dir_name):
      shutil.move(os.path.join(dir_name, i), i)
    os.rmdir(dir_name)

    # modify cgi script
    cgi_path = os.path.join(location, 'httpd', 'cgi-bin', 'check')
    cgi = file(cgi_path).read()
    cgi = cgi.replace('#!/usr/bin/perl', '#!%s' % options['perl-path'])
    default_config_path = os.path.join(location, 'htdocs', 'config',
                                       'validator.conf')
    cgi = cgi.replace('/etc/w3c/validator.conf',
                options['config-path'] or \
                default_config_path)
    file(cgi_path, 'w').write(cgi)

    # modify config file
    if not options['config-path']:
      config_path = default_config_path
      config = file(config_path).read()
      config = config.replace('#Base = /usr/local/validator',
                     'Base = %s' % location)
      file(config_path, 'w').write(config)

    return [location,]

  def update(self):
    pass
